@@ -1,373 +1,351 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
 <context>
-    <name>QApplication</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="main.cpp" line="53"/>
-        <source>You must run this program as root.</source>
-        <translation>Cal ser usuari principal per executar aquest programa</translation>
-    </message>
-</context>
-<context>
-    <name>bootrepair</name>
-    <message>
-        <location filename="bootrepair.ui" line="20"/>
-        <location filename="bootrepair.cpp" line="445"/>
-        <location filename="ui_bootrepair.h" line="389"/>
+        <location filename="mainwindow.ui" line="20"/>
         <source>Boot Repair</source>
         <translation>Repara l&apos;arrencada </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="39"/>
+        <location filename="mainwindow.ui" line="39"/>
         <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
         <translation>Boot Repair és una utilitat que es pot usar per a reinstal·lar el carregador GRUB als sitemes ESP (EFI System Partition), MBR (Master Boot Record) o a la partició arrel. Dóna l&apos;opció de reconstruir el fitxer de configuració del GRUB i fer còpia de seguretat o restaurar el MBR o PBR (arrel).</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="58"/>
-        <location filename="ui_bootrepair.h" line="391"/>
+        <location filename="mainwindow.ui" line="58"/>
         <source>What would you like to do?</source>
         <translation>Què voldríeu fer?</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="79"/>
-        <location filename="ui_bootrepair.h" line="392"/>
+        <location filename="mainwindow.ui" line="79"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Còpia de seguretat del MBR o PBR (només arrencada antiga)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="86"/>
+        <location filename="mainwindow.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
         <translation>Reinstal·la el carregador GRUB en ESP, MBR o PBR (root)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="96"/>
-        <location filename="ui_bootrepair.h" line="394"/>
+        <location filename="mainwindow.ui" line="96"/>
         <source>Repair GRUB configuration file</source>
         <translation>Repara el fitxer de configuració del GRUB</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="103"/>
-        <location filename="ui_bootrepair.h" line="395"/>
+        <location filename="mainwindow.ui" line="103"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
         <translation>Restaura el MBR o PBR de la còpia de seguretat (només arrencada antiga)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="123"/>
-        <location filename="bootrepair.cpp" line="378"/>
-        <location filename="ui_bootrepair.h" line="396"/>
+        <location filename="mainwindow.ui" line="136"/>
+        <location filename="mainwindow.cpp" line="485"/>
         <source>Select Boot Method</source>
         <translation>Trieu el mètode d&apos;arrencada</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="141"/>
-        <location filename="ui_bootrepair.h" line="398"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Master Boot Record</source>
         <translation>Registre d&apos;Arrencada Principal</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="144"/>
-        <location filename="ui_bootrepair.h" line="400"/>
+        <location filename="mainwindow.ui" line="157"/>
         <source>MBR</source>
         <translation>MBR</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="147"/>
-        <location filename="bootrepair.ui" line="418"/>
-        <location filename="ui_bootrepair.h" line="401"/>
-        <location filename="ui_bootrepair.h" line="420"/>
+        <location filename="mainwindow.ui" line="160"/>
+        <location filename="mainwindow.ui" line="430"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="169"/>
-        <location filename="ui_bootrepair.h" line="403"/>
+        <location filename="mainwindow.ui" line="182"/>
         <source>Root (Partition Boot Record)</source>
         <translation>Arrel (Registre d&apos;Arrencada de Partició)</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="172"/>
-        <location filename="bootrepair.cpp" line="380"/>
-        <location filename="ui_bootrepair.h" line="405"/>
+        <location filename="mainwindow.ui" line="185"/>
+        <location filename="mainwindow.cpp" line="488"/>
         <source>root</source>
         <translation>Arrel</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="223"/>
-        <location filename="bootrepair.cpp" line="379"/>
-        <location filename="ui_bootrepair.h" line="406"/>
+        <location filename="mainwindow.ui" line="236"/>
+        <location filename="mainwindow.cpp" line="487"/>
         <source>Install on:</source>
         <translation>Instal·la a: </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="242"/>
-        <location filename="ui_bootrepair.h" line="407"/>
+        <location filename="mainwindow.ui" line="255"/>
+        <location filename="mainwindow.cpp" line="486"/>
         <source>Location:</source>
         <translation>Ubicació: </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="264"/>
-        <location filename="ui_bootrepair.h" line="411"/>
-        <source>Select /boot location:</source>
-        <translation>Trieu la ubicació de /boot: </translation>
+        <location filename="mainwindow.ui" line="277"/>
+        <location filename="mainwindow.cpp" line="496"/>
+        <source>Select root location:</source>
+        <translation>trieu la ubicació de l&apos;arrel:</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="277"/>
-        <location filename="ui_bootrepair.h" line="413"/>
+        <location filename="mainwindow.ui" line="290"/>
         <source>EFI System Partition</source>
-        <translation>EFI System Partition</translation>
+        <translation>Partició de Sistema EFI </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="280"/>
-        <location filename="ui_bootrepair.h" line="415"/>
+        <location filename="mainwindow.ui" line="293"/>
         <source>ESP</source>
         <translation>ESP</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="407"/>
-        <location filename="ui_bootrepair.h" line="417"/>
+        <location filename="mainwindow.ui" line="420"/>
         <source>About this application</source>
         <translation>Quant a aquest programa</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="410"/>
-        <location filename="ui_bootrepair.h" line="419"/>
+        <location filename="mainwindow.ui" line="423"/>
         <source>About...</source>
         <translation>Quant a...</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="460"/>
-        <location filename="ui_bootrepair.h" line="422"/>
+        <location filename="mainwindow.ui" line="472"/>
         <source>Display help </source>
         <translation>Mostra l&apos;ajuda</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="463"/>
-        <location filename="ui_bootrepair.h" line="424"/>
+        <location filename="mainwindow.ui" line="475"/>
         <source>Help</source>
         <translation>Ajuda </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="471"/>
-        <location filename="ui_bootrepair.h" line="425"/>
+        <location filename="mainwindow.ui" line="482"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="512"/>
-        <location filename="ui_bootrepair.h" line="428"/>
+        <location filename="mainwindow.ui" line="523"/>
         <source>Cancel any changes then quit</source>
         <translation>Cancel·la els canvis i surt </translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="515"/>
-        <location filename="bootrepair.cpp" line="450"/>
-        <location filename="ui_bootrepair.h" line="430"/>
+        <location filename="mainwindow.ui" line="526"/>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="523"/>
-        <location filename="ui_bootrepair.h" line="431"/>
+        <location filename="mainwindow.ui" line="533"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="542"/>
-        <location filename="ui_bootrepair.h" line="433"/>
+        <location filename="mainwindow.ui" line="552"/>
         <source>Apply any changes</source>
         <translation>Aplica els canvis</translation>
     </message>
     <message>
-        <location filename="bootrepair.ui" line="545"/>
-        <location filename="bootrepair.cpp" line="78"/>
-        <location filename="ui_bootrepair.h" line="435"/>
+        <location filename="mainwindow.ui" line="555"/>
+        <location filename="mainwindow.cpp" line="70"/>
         <source>Apply</source>
         <translation>Aplica</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="96"/>
+        <location filename="mainwindow.cpp" line="86"/>
         <source>GRUB is being installed on %1 device.</source>
         <translation>S&apos;està instal·lant GRUB al dispositiu %1 .</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="111"/>
-        <location filename="bootrepair.cpp" line="134"/>
-        <location filename="bootrepair.cpp" line="164"/>
-        <location filename="bootrepair.cpp" line="266"/>
-        <location filename="bootrepair.cpp" line="300"/>
-        <location filename="bootrepair.cpp" line="418"/>
-        <location filename="bootrepair.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="118"/>
+        <location filename="mainwindow.cpp" line="203"/>
+        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="419"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="534"/>
+        <location filename="mainwindow.cpp" line="597"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="112"/>
-        <source>Could not mount </source>
-        <translation>No es pot muntar </translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="112"/>
-        <source> on /boot/efi</source>
-        <translation>a /boot/efi</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="135"/>
-        <location filename="bootrepair.cpp" line="165"/>
+        <location filename="mainwindow.cpp" line="119"/>
+        <location filename="mainwindow.cpp" line="204"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
         <translation>No es pot establir l&apos;entorn de chroot.
 Si us plau, verifiqueu la ubicació triada. </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="152"/>
+        <location filename="mainwindow.cpp" line="179"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>S&apos;està reconstruint el fitxer de configuració del GRUB (grub.cfg).</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="186"/>
+        <location filename="mainwindow.cpp" line="222"/>
         <source>Backing up MBR or PBR from %1 device.</source>
         <translation>Fent còpia de seguretat del MBR o PBR del dispositiu %1 .</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="241"/>
+        <location filename="mainwindow.cpp" line="287"/>
         <source>Warning</source>
         <translation>Atenció </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source>You are going to write the content of </source>
         <translation>Ara s&apos;enregistrarà el contingut de </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source> to </source>
         <translation>a</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="242"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source>
 
 Are you sure?</source>
         <translation>
 
-N&apos;esteu segur? </translation>
+N&apos;esteu segurs? </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="243"/>
-        <location filename="bootrepair.cpp" line="296"/>
-        <source>Yes</source>
-        <translation>Sí </translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="243"/>
-        <location filename="bootrepair.cpp" line="296"/>
-        <source>No</source>
-        <translation>No </translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="247"/>
+        <location filename="mainwindow.cpp" line="293"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Restaurant el MBR/PBR de la còpia de seguretat al dispositiu %1 .</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="313"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>No trobo la partició EFI de sistema (ESP) a cap disc del sistema. Si us plau, creeu un ESP i torneu a provar-ho.</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="294"/>
-        <source>Success</source>
-        <translation>Èxit</translation>
+        <location filename="mainwindow.cpp" line="348"/>
+        <source>Select %1 location:</source>
+        <translation>Trieu la ubicació de %1 :</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="295"/>
-        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
-        <translation>Procés acabat amb èxit.&lt;p&gt;&lt;b&gt;Voleu sortir de Boot Repair?&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="301"/>
-        <source>Process finished. Errors have occurred.</source>
-        <translation>El procés ha acabat. Hi ha hagut errors.</translation>
-    </message>
-    <message>
-        <location filename="bootrepair.cpp" line="303"/>
+        <location filename="mainwindow.cpp" line="372"/>
         <source>Back</source>
         <translation>Enrere</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="387"/>
+        <location filename="mainwindow.cpp" line="388"/>
+        <source>Success</source>
+        <translation>Èxit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="389"/>
+        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
+        <translation>Procés acabat amb èxit.&lt;p&gt;&lt;b&gt;Voleu sortir de Boot Repair?&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="395"/>
+        <source>Process finished. Errors have occurred.</source>
+        <translation>El procés ha acabat. Hi ha hagut errors.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="412"/>
+        <source>Enter password to unlock %1 encrypted partition:</source>
+        <translation>Entreu la contrasenya per desbloquejar la partició encriptada %1:</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="420"/>
+        <source>Sorry, could not open %1 LUKS container</source>
+        <translation>Ho sento, no puc configurar el contenidor LUKS %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="495"/>
         <source>Select GRUB location</source>
         <translation>Trieu la ubicació de GRUB </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="398"/>
+        <location filename="mainwindow.cpp" line="507"/>
         <source>Select Item to Back Up</source>
         <translation>Trieu l&apos;element per fer còpia de seguretat</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="405"/>
+        <location filename="mainwindow.cpp" line="514"/>
         <source>Select Item to Restore</source>
         <translation>Trieu l&apos;element a restaurar</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="416"/>
+        <location filename="mainwindow.cpp" line="525"/>
         <source>Select backup file name</source>
         <translation>Trieu el nom del fitxer de còpia de seguretat </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="418"/>
-        <location filename="bootrepair.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="534"/>
         <source>No file was selected.</source>
         <translation>No s&apos;ha triat cap fitxer. </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="423"/>
+        <location filename="mainwindow.cpp" line="532"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Trieu un fitxer de còpia de seguretat de MBR o PBR </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="444"/>
-        <source>About Boot Repair</source>
-        <translation>Quant a Boot Repair</translation>
+        <location filename="mainwindow.cpp" line="552"/>
+        <source>About %1</source>
+        <translation>Quant a %1</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="445"/>
+        <location filename="mainwindow.cpp" line="553"/>
         <source>Version: </source>
         <translation>Versió: </translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="447"/>
+        <location filename="mainwindow.cpp" line="554"/>
         <source>Simple boot repair program for antiX Linux</source>
         <translation>Programa senzill per reparar l&apos;arrencada a antiX Linux</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="448"/>
+        <location filename="mainwindow.cpp" line="556"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="449"/>
+        <location filename="mainwindow.cpp" line="557"/>
+        <source>%1 License</source>
+        <translation>Llicència de %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="571"/>
+        <source>%1 Help</source>
+        <translation>Ajuda de %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="598"/>
+        <source>Sorry, could not mount %1 partition</source>
+        <translation>Ho sento, no puc muntar la partició %1</translation>
+    </message>
+</context>
+<context>
+    <name>QApplication</name>
+    <message>
+        <location filename="about.cpp" line="32"/>
         <source>License</source>
         <translation>Llicència</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="452"/>
-        <source>&apos;Boot Repair License&apos;</source>
-        <translation>&apos;Llicència de Boot Repair&apos;</translation>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>Registre de canvis</translation>
     </message>
     <message>
-        <location filename="bootrepair.cpp" line="461"/>
-        <source>&apos;Boot Repair Help&apos;</source>
-        <translation>&apos;Ajuda de Boot Repair&apos;</translation>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>Cancel·la</translation>
     </message>
     <message>
-        <location filename="ui_bootrepair.h" line="390"/>
-        <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation>Boot repair és una eina que es pot usar per reinstal·lar el carregador GRUB al MBR (Master Boot Record) o la partició arrel. Dóna l&apos;opció de reconstruir el fitxer de configuració GRUB i fer còpia de seguretat del MBR o PBR.</translation>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>Tan&amp;ca </translation>
     </message>
     <message>
-        <location filename="ui_bootrepair.h" line="393"/>
-        <source>Reinstall GRUB bootloader</source>
-        <translation>Reinstal·la el carregador GRUB</translation>
+        <location filename="main.cpp" line="64"/>
+        <source>You must run this program as root.</source>
+        <translation>Cal ser usuari principal per executar aquest programa</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
